package main

import (
	"bufio"
	"fmt"
	"os"
	"path/filepath"

	"github.com/BurntSushi/toml"
	"github.com/urfave/cli"

	"gitlab.33.cn/link33/sidecar/internal/repo"
	"gitlab.33.cn/link33/sidecar/tool"
)

var initCMD = cli.Command{
	Name:  "init",
	Usage: "Initialize sidecar local configuration",
	Action: func(ctx *cli.Context) error {
		repoRoot, err := repo.PathRootWithDefault(ctx.GlobalString("repo"))
		if err != nil {
			return err
		}

		path := filepath.Join(repoRoot, repo.ConfigName)
		if tool.Exist(path) {
			fmt.Println("sidecar configuration file already exists")
			fmt.Println("reinitializing would overwrite your configuration, Y/N?")
			input := bufio.NewScanner(os.Stdin)
			input.Scan()
			if input.Text() == "Y" || input.Text() == "y" {
				err = repo.Initialize(repoRoot)
			}
		} else {
			err = repo.Initialize(repoRoot)
		}
		if err != nil {
			return err
		}
		return afterWork(ctx, path)
	},
}

func afterWork(ctx *cli.Context, path string) error {
	id, err := LoadID(ctx)
	if err != nil {
		return err
	}
	config := &repo.Config{}
	_, err = toml.DecodeFile(path, config)
	if err != nil {
		return err
	}
	if len(config.Peer.Peers) == 0 {
		config.Peer.Peers = make([]string, 1)
	}
	config.Peer.Peers[0] = fmt.Sprintf("/ip4/127.0.0.1/tcp/4000/p2p/%s", id)
	file, err := os.OpenFile(path, os.O_RDWR|os.O_TRUNC|os.O_CREATE, os.FileMode(0o766))
	if err != nil {
		return err
	}
	return toml.NewEncoder(file).Encode(config)
}
